@@ -1,4 +1,4 @@
-# Copyright (C) 2003, 2004  Free Software Foundation, Inc.
+# Copyright (C) 2003, 2004, 2006, 2007  Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -104,11 +104,11 @@ use constant GNITS   => 2;
 
 =item C<$strictness>
 
-The current stricness.  One of C<FOREIGN>, C<GNU>, or C<GNITS>.
+The current strictness.  One of C<FOREIGN>, C<GNU>, or C<GNITS>.
 
 =item C<$strictness_name>
 
-The current stricness name.  One of C<'foreign'>, C<'gnu'>, or C<'gnits'>.
+The current strictness name.  One of C<'foreign'>, C<'gnu'>, or C<'gnits'>.
 
 =back
 
@@ -159,7 +159,7 @@ Query the state of an option.  If the option is unset, this
 returns the empty list.  Otherwise it returns the option's value,
 as set by C<set_option> or C<set_global_option>.
 
-Not that C<global_option> should be used only when it is
+Note that C<global_option> should be used only when it is
 important to make sure an option hasn't been set locally.
 Otherwise C<option> should be the standard function to
 check for options (be they global or local).
@@ -239,7 +239,7 @@ Return 1 on error, 0 otherwise.
 # -------------------------------------------------
 # Process a list of options.  Return 1 on error, 0 otherwise.
 # \%OPTIONS is the hash to fill with options data, $WHERE is
-# the location where @OPTIONS occured.
+# the location where @OPTIONS occurred.
 sub _process_option_list (\%$@)
 {
   my ($options, $where, @list) = @_;
@@ -261,6 +261,7 @@ sub _process_option_list (\%$@)
       elsif ($_ eq 'no-installman' || $_ eq 'no-installinfo'
 	     || $_ eq 'dist-shar' || $_ eq 'dist-zip'
 	     || $_ eq 'dist-tarZ' || $_ eq 'dist-bzip2'
+	     || $_ eq 'dist-lzma'
 	     || $_ eq 'no-dist-gzip' || $_ eq 'no-dist'
 	     || $_ eq 'dejagnu' || $_ eq 'no-texinfo.tex'
 	     || $_ eq 'readme-alpha' || $_ eq 'check-news'
