@@ -1,4 +1,4 @@
-# Copyright (C) 2003, 2004, 2005  Free Software Foundation, Inc.
+# Copyright (C) 2003, 2004, 2005, 2006, 2008  Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -73,7 +73,7 @@ Automake::Variable - support for variable definitions
   # $var->conditions->conds is a list of Automake::Condition.)
   my @conds = $var->conditions->conds
 
-  # Accessing to the definition in Condition $cond.
+  # Access to the definition in Condition $cond.
   # $def is an Automake::VarDef.
   my $def = $var->def ($cond);
   if ($def)
@@ -137,11 +137,16 @@ my $_VARIABLE_PATTERN = '^[.A-Za-z0-9_@]+' . "\$";
 my @_var_order;
 
 # This keeps track of all variables defined by &_gen_varname.
-# $_gen_varname{$base} is a hash for all variable defined with
-# prefix `$base'.  Values stored this this hash are the variable names.
+# $_gen_varname{$base} is a hash for all variables defined with
+# prefix `$base'.  Values stored in this hash are the variable names.
 # Keys have the form "(COND1)VAL1(COND2)VAL2..." where VAL1 and VAL2
 # are the values of the variable for condition COND1 and COND2.
 my %_gen_varname = ();
+# $_gen_varname_n{$base} is the number of variables generated by
+# _gen_varname() for $base.  This is not the same as keys
+# %{$_gen_varname{$base}} because %_gen_varname may also contain
+# variables not generated by _gen_varname.
+my %_gen_varname_n = ();
 
 # Declare the macros that define known variables, so we can
 # hint the user if she try to use one of these variables.
@@ -177,14 +182,18 @@ my %_ac_macro_for_var =
    F77FLAGS => 'AC_PROG_F77',
    FC => 'AC_PROG_FC',
    FCFLAGS => 'AC_PROG_FC',
+   OBJC => 'AC_PROG_OBJC',
+   OBJCFLAGS => 'AC_PROG_OBJC',
    RANLIB => 'AC_PROG_RANLIB',
+   UPC => 'AM_PROG_UPC',
+   UPCFLAGS => 'AM_PROG_UPC',
    YACC => 'AC_PROG_YACC',
    );
 
 # The name of the configure.ac file.
 my $configure_ac = find_configure_ac;
 
-# Variables that can be overriden without complaint from -Woverride
+# Variables that can be overridden without complaint from -Woverride
 my %_silent_variable_override =
   (AM_MAKEINFOHTMLFLAGS => 1,
    AR => 1,
@@ -293,17 +302,33 @@ sub hook ($$)
   $_hooks{$var} = $fun;
 }
 
-=item C<variables>
+=item C<variables ([$suffix])>
 
 Returns the list of all L<Automake::Variable> instances.  (I.e., all
-variables defined so far.)
+variables defined so far.)  If C<$suffix> is supplied, return only
+the L<Automake::Variable> instances that ends with C<_$suffix>.
 
 =cut
 
-use vars '%_variable_dict';
-sub variables ()
+use vars '%_variable_dict', '%_primary_dict';
+sub variables (;$)
 {
-  return values %_variable_dict;
+  my ($suffix) = @_;
+  if ($suffix)
+    {
+      if (exists $_primary_dict{$suffix})
+	{
+	  return values %{$_primary_dict{$suffix}};
+	}
+      else
+	{
+	  return ();
+	}
+    }
+  else
+    {
+      return values %_variable_dict;
+    }
 }
 
 =item C<Automake::Variable::reset>
@@ -316,9 +341,11 @@ other internal data.
 sub reset ()
 {
   %_variable_dict = ();
+  %_primary_dict = ();
   $_appendvar = 0;
   @_var_order = ();
   %_gen_varname = ();
+  %_gen_varname_n = ();
   $_traversal = 0;
 }
 
@@ -419,6 +446,10 @@ sub _new ($$)
   $self->{'scanned'} = 0;
   $self->{'last-append'} = []; # helper variable for last conditional append.
   $_variable_dict{$name} = $self;
+  if ($name =~ /_([[:alnum:]]+)$/)
+    {
+      $_primary_dict{$1}{$name} = $self;
+    }
   return $self;
 }
 
@@ -712,7 +743,7 @@ sub scan_variable_expansions ($)
   while ($text =~ /(?<!\$)\$(?:\{([^\}]*)\}|\(([^\)]*)\))/g)
     {
       my $var = $1 || $2;
-      # The occurence may look like $(string1[:subst1=[subst2]]) but
+      # The occurrence may look like $(string1[:subst1=[subst2]]) but
       # we want only `string1'.
       $var =~ s/:[^:=]*=[^=]*$//;
       push @result, $var;
@@ -758,7 +789,7 @@ C<$varname>: the name of the variable being defined.
 
 C<$owner>: owner of the variable (one of C<VAR_MAKEFILE>,
 C<VAR_CONFIGURE>, or C<VAR_AUTOMAKE>, defined by L<Automake::VarDef>).
-Variables can be overriden, provided the new owner is not weaker
+Variables can be overridden, provided the new owner is not weaker
 (C<VAR_AUTOMAKE> < C<VAR_CONFIGURE> < C<VAR_MAKEFILE>).
 
 C<$type>: the type of the assignment (C<''> for C<FOO = bar>,
@@ -1020,6 +1051,10 @@ sub variable_delete ($@)
 	  delete $_variable_dict{$var}{'defs'}{$cond};
 	}
     }
+  if ($var =~ /_([[:alnum:]]+)$/)
+    {
+      delete $_primary_dict{$1}{$var};
+    }
 }
 
 =item C<$str = variables_dump>
@@ -1073,7 +1108,7 @@ sub set_seen ($)
 
 Make sure that each supplied variable is defined in C<$cond>.
 Otherwise, issue a warning showing C<$reason> (C<$reason> should be
-the reason why these variable are required, for instance C<'option foo
+the reason why these variables are required, for instance C<'option foo
 used'>).  If we know which macro can define this variable, hint the
 user.  Return the number of undefined variables.
 
@@ -1100,21 +1135,28 @@ sub require_variables ($$$@)
 	  next VARIABLE
 	    if $undef_cond->false;
 	  $text .= ("in the following conditions:\n  "
-		    . join ("\n  ", map { $_->human } $undef_cond->conds));
+		    . join ("\n  ", map { $_->human } $undef_cond->conds)
+		    . "\n");
 	}
 
       ++$res;
 
       if (exists $_am_macro_for_var{$var})
 	{
-	  $text .= "\nThe usual way to define `$var' is to add "
-	    . "`$_am_macro_for_var{$var}'\nto `$configure_ac' and "
-	    . "run `aclocal' and `autoconf' again.";
+	  my $mac = $_am_macro_for_var{$var};
+	  $text .= "  The usual way to define `$var' is to add "
+	    . "`$mac'\n  to `$configure_ac' and run `aclocal' and "
+	    . "`autoconf' again.";
+	  # aclocal will not warn about undefined macros unless it
+	  # starts with AM_.
+	  $text .= "\n  If `$mac' is in `$configure_ac', make sure\n"
+	    . "  its definition is in aclocal's search path."
+	    unless $mac =~ /^AM_/;
 	}
       elsif (exists $_ac_macro_for_var{$var})
 	{
-	  $text .= "\nThe usual way to define `$var' is to add "
-	    . "`$_ac_macro_for_var{$var}'\nto `$configure_ac' and "
+	  $text .= "  The usual way to define `$var' is to add "
+	    . "`$_ac_macro_for_var{$var}'\n  to `$configure_ac' and "
 	    . "run `autoconf' again.";
 	}
 
@@ -1148,7 +1190,7 @@ sub requires_variables ($$@)
 
 Get the C<TRUE> value of a variable, warn if the variable is
 conditionally defined.  C<$var> can be either a variable name
-or a C<Automake::Variable> instance (this allows to calls sucha
+or a C<Automake::Variable> instance (this allows calls such
 as C<$var-E<gt>variable_value>).
 
 =cut
@@ -1159,7 +1201,8 @@ sub variable_value ($)
     my $v = ref ($var) ? $var : var ($var);
     return () unless $v;
     $v->check_defined_unconditionally;
-    return $v->rdef (TRUE)->value;
+    my $d = $v->def (TRUE);
+    return $d ? $d->value : "";
 }
 
 =item C<$str = output_variables>
@@ -1220,13 +1263,13 @@ following arguments:
                    traversing
    $val,        -- the item (i.e., filename) to process
    $cond,       -- the Condition for the $var definition we are
-                   examinating (ignoring the recursion context)
+                   examining (ignoring the recursion context)
    $full_cond)  -- the full Condition, taking into account
                    conditions inherited from parent variables
                    during recursion
 
-If C<inner_expand> is set, variable references occuring in filename
-(as in C<$(BASE).ext>) are expansed before the filename is passed to
+If C<inner_expand> is set, variable references occurring in filename
+(as in C<$(BASE).ext>) are expanded before the filename is passed to
 C<&fun_item>.
 
 If C<skip_ac_subst> is set, Autoconf @substitutions@ will be skipped,
@@ -1428,14 +1471,48 @@ sub _do_recursive_traversal ($$&&$$$$)
   return &$fun_collect ($var, $parent_cond, @allresults);
 }
 
-# $VARNAME
+# _hash_varname ($VAR)
+# --------------------
+# Compute the key associated $VAR in %_gen_varname.
+# See _gen_varname() below.
+sub _hash_varname ($)
+{
+  my ($var) = @_;
+  my $key = '';
+  foreach my $cond ($var->conditions->conds)
+    {
+      my @values = $var->value_as_list ($cond);
+      $key .= "($cond)@values";
+    }
+  return $key;
+}
+
+# _hash_values (@VALUES)
+# ----------------------
+# Hash @VALUES for %_gen_varname.  @VALUES should be a list
+# of pairs: ([$cond, @values], [$cond, @values], ...).
+# See _gen_varname() below.
+sub _hash_values (@)
+{
+  my $key = '';
+  foreach my $pair (@_)
+    {
+      my ($cond, @values) = @$pair;
+      $key .= "($cond)@values";
+    }
+  return $key;
+}
+# ($VARNAME, $GENERATED)
 # _gen_varname ($BASE, @DEFINITIONS)
 # ---------------------------------
 # Return a variable name starting with $BASE, that will be
 # used to store definitions @DEFINITIONS.
 # @DEFINITIONS is a list of pair [$COND, @OBJECTS].
 #
-# If we already have a $BASE-variable containing @DEFINITIONS, reuse it.
+# If we already have a $BASE-variable containing @DEFINITIONS, reuse
+# it and set $GENERATED to 0.  Otherwise construct a new name and set
+# $GENERATED to 1.
+#
 # This way, we avoid combinatorial explosion of the generated
 # variables.  Especially, in a Makefile such as:
 #
@@ -1466,19 +1543,17 @@ sub _do_recursive_traversal ($$&&$$$$)
 sub _gen_varname ($@)
 {
   my $base = shift;
-  my $key = '';
-  foreach my $pair (@_)
-    {
-      my ($cond, @values) = @$pair;
-      $key .= "($cond)@values";
-    }
+  my $key = _hash_values @_;
 
-  return $_gen_varname{$base}{$key} if exists $_gen_varname{$base}{$key};
+  return ($_gen_varname{$base}{$key}, 0)
+    if exists $_gen_varname{$base}{$key};
 
-  my $num = 1 + keys (%{$_gen_varname{$base}});
+  my $num = 1 + ($_gen_varname_n{$base} || 0);
+  $_gen_varname_n{$base} = $num;
   my $name = "${base}_${num}";
   $_gen_varname{$base}{$key} = $name;
-  return $name;
+
+  return ($name, 1);
 }
 
 =item C<$resvar = transform_variable_recursively ($var, $resvar, $base, $nodefine, $where, &fun_item, [%options])>
@@ -1518,16 +1593,28 @@ sub transform_variable_recursively ($$$$$&;%)
 
   my $res = $var->traverse_recursively
     ($fun_item,
-     # The code that define the variable holding the result
+     # The code that defines the variable holding the result
      # of the recursive transformation of a subvariable.
      sub {
        my ($subvar, $parent_cond, @allresults) = @_;
+       # If no definition is required, return anything: the result is
+       # not expected to be used, only the side effect of $fun_item
+       # should matter.
+       return 'report-me' if $nodefine;
+       # Cache $subvar, so that we reuse it if @allresults is the same.
+       my $key = _hash_varname $subvar;
+       $_gen_varname{$base}{$key} = $subvar->name;
+
        # Find a name for the variable, unless this is the top-variable
        # for which we want to use $resvar.
-       my $varname =
-	 ($var != $subvar) ? _gen_varname ($base, @allresults) : $resvar;
-       # Define the variable if required.
-       unless ($nodefine)
+       my ($varname, $generated) =
+	 ($var != $subvar) ? _gen_varname ($base, @allresults) : ($resvar, 1);
+
+       # Define the variable if we are not reusing a previously
+       # defined variable.  At the top-level, we can also avoid redefining
+       # the variable if it already contains the same values.
+       if ($generated
+	   && !($varname eq $var->name && $key eq _hash_values @allresults))
 	 {
 	   # If the new variable is the source variable, we assume
 	   # we are trying to override a user variable.  Delete
@@ -1552,8 +1639,8 @@ sub transform_variable_recursively ($$$$$&;%)
 			   '', $where, VAR_PRETTY);
 		 }
 	     }
-	   set_seen $varname;
 	 }
+       set_seen $varname;
        return "\$($varname)";
      },
      %options);
